@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20121228';
+our $VERSION = '0.20130131';
 
-# Table last modified: 2012-12-28
+# Table last modified: 2013-01-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -104,10 +104,10 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:0[1-4]|1[035])|101))',
+    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|5[2489]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:0[1-4]|1[035])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|1[02-79]|3[0-57-9]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|2[014589]|5[167]|7[27]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
     '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[257-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
@@ -130,7 +130,7 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
@@ -217,7 +217,7 @@ our %ZIP_TABLE = (
     '235' => '(?:85(?:[58]8|2[23]|0[15]))',
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
-    '238' => '(?:(?:8(?:5(?:41|8[058]|1[013]|2[02]|3[35]|6[57]|5[08])|6[18]6)|029[28]))',
+    '238' => '(?:(?:8(?:5(?:8[058]|1[013]|2[02]|3[35]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|50|8[58])|68[68]))',
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
@@ -233,16 +233,16 @@ our %ZIP_TABLE = (
     '251' => '(?:8(?:5(?:40|2[02]|5[0158]|1[0135]|6[067]|8[18]|3[014]|0[125])|601))',
     '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|5[258]|1[01]|2[125]|9[2-578])|1(?:[56]2|7[27]|9[1256]|8[1-3589]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:01|10|22|43|67|7[17]|5[058]|8[58]|3[01])|686)|019[25-8]))',
-    '254' => '(?:8(?:5(?:43|55|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
+    '254' => '(?:8(?:5(?:43|55|67|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
     '256' => '(?:8510)',
     '257' => '(?:8(?:5(?:11|33|55|66|2[23]|0[12]|8[4-68])|686))',
     '258' => '(?:(?:85(?:11|85|3[38]|0[168])|0195))',
     '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|39[26])|0(?:19[2-46-8]|39[2356])))',
     '260' => '(?:8(?:6(?:2[0-24-79]|0[13-7]|5[46]|4[2578]|1[0-3689]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|2[134]|8[0568]|7[257]|3[2458]|1[0-68]|0[1-35-9]|5[0-24-9]|6[02-7])|7(?:3[03]|1[02357]|2[02]|0[1-37])))',
-    '261' => '(?:8(?:5(?:30|66|75|5[245]|4[45]|1[235]|2[0-2]|8[126-8]|0[1-378])|6(?:09|86)|733))',
+    '261' => '(?:8(?:5(?:66|75|3[03]|5[245]|4[45]|1[235]|2[0-2]|8[126-8]|0[1-378])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:36|55|0[2-468]|1[0-2])|7(?:10|33)))',
-    '263' => '(?:8(?:5(?:[12]2|06|33|77|8[58]|5[05])|733))',
+    '263' => '(?:8(?:5(?:[12]2|33|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[35]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
@@ -304,7 +304,7 @@ our %ZIP_TABLE = (
     '328' => '(?:(?:8(?:5(?:33|5[0568]|8[568]|0[1-5])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:1(?:19[3-68]|39[2-5]|292|493)|0(?:59[568]|49[28]|69[26]|195)|2(?:79[237]|19[23]|99[23]|292)|4(?:49[23]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|6[4-6]|3[156]|2[35]|7[57]|1[0-2]|0[1-37-9]|8[0-3568])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:01|30|77|1[01])|7(?:15|9[67])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|8[015]|0[3568]|3[238]|1[0189]|2[29]|7[129]|5[01]|6[56])|6(?:01|69|8[68]))))',
-    '331' => '(?:(?:8(?:5(?:[24]0|01|1[13]|5[02]|6[07]|3[237]|8[06-8])|6(?:33|58|8[6-8]))|9(?:5(?:[1-35]0|77)|624)))',
+    '331' => '(?:(?:8(?:5(?:[24]0|01|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:33|58|8[6-8]))|9(?:5(?:[1-35]0|77)|624)))',
     '332' => '(?:8(?:5(?:21|48|77|85|5[568]|0[12]|1[0-2])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
     '334' => '(?:8501)',
@@ -346,7 +346,7 @@ our %ZIP_TABLE = (
     '370' => '(?:(?:8(?:5(?:[01]1|22|43|65|3[17]|8[58]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[235]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
     '371' => '(?:(?:8(?:5(?:39|43|67|70|85|0[1-578]|2[25]|1[0-467]|5[01])|6(?:[01]1|[68]6|40))|0(?:192|294)))',
     '372' => '(?:8(?:5(?:58|67|8[058]|0[128])|686))',
-    '373' => '(?:8(?:5(?:21|40|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[06]|3[09]|8[68]|1[01])|718))',
+    '373' => '(?:8(?:5(?:21|40|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|39|6[06]|8[68]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|33|55|77|88|2[01]|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-6]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|0[1-3]|1[056]|2[38]|[58][58])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
@@ -411,11 +411,11 @@ our %ZIP_TABLE = (
     '437' => '(?:(?:1(?:6(?:8[6-8]|9[2-8])|19[2-7]|39[2357]|49[24-6]|59[2-4]|292)|8(?:5(?:[01]1|[45]5)|6(?:[01]1|[68]6))|0(?:29[23]|693)))',
     '438' => '(?:(?:8(?:5(?:01|10|43|77|85|5[058])|6(?:[01]1|22|50|86)|71[18])|0(?:19[235]|292)))',
     '439' => '(?:865[01])',
-    '440' => '(?:8(?:5(?:1\d|3[0-3]|0[124-8]|2[0-8])|60[1-4]))',
-    '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|8[08]|0[1-37]|1[0-2579]|4[035]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
+    '440' => '(?:8(?:5(?:43|1\d|3[0-3]|0[124-8]|2[0-8])|60[1-4]))',
+    '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|4[05]|8[08]|0[1-37]|1[0-2579]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
     '442' => '(?:8(?:5(?:20|58|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|8[0-25-8]|7[35-7]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:55|88)|6[01]1)|019[2-4]))',
-    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[23]|89[23])))',
+    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[12478]|3[35]|0[1-8]|[58][58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
@@ -488,7 +488,7 @@ our %ZIP_TABLE = (
     '516' => '(?:(?:8(?:5(?:20|77|5[0-58]|4[3-9]|6[67]|1[12568]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:49[2-68]|29[2-6]|192)|85(?:01|18|33)))',
-    '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|2(?:59[23]|[17]92)|3(?:69[2-6]|492)|439[2-6]|529[23]|1192))',
+    '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|7[057]|5[058]|1[1-356])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[0-2])1|0[23]92))',
     '522' => '(?:(?:8(?:5(?:11|40|3[39]|0[13]|8[58]|2[023])|6(?:55|66))|029[27]))',
@@ -524,7 +524,7 @@ our %ZIP_TABLE = (
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
     '554' => '(?:85(?:[01]1|[58][58]))',
     '555' => '(?:85(?:55|0[12]))',
-    '556' => '(?:8(?:5(?:01|85|5[058]|1[0256])|6(?:01|70|6[03-6])))',
+    '556' => '(?:8(?:5(?:85|0[13]|5[058]|1[0256])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[12]|6[01])|6(?:[01]1|5[18])|729))',
@@ -612,7 +612,7 @@ our %ZIP_TABLE = (
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
     '650' => '(?:8(?:5(?:43|1[015]|5[01589]|2[0-258]|6[057]|3[0369]|7[015-7]|8[04-689]|0[1-35])|6(?:[68][06]|7[07])|7(?:87|94)))',
-    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[07]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
+    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[078]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
     '653' => '(?:85(?:70|85))',
     '654' => '(?:(?:85(?:70|85)|019[2358]))',
@@ -689,7 +689,7 @@ our %ZIP_TABLE = (
     '729' => '(?:(?:3(?:49[278]|19[23]|592)|0(?:49[25]|292|393)|2(?:39[2-5]|292)|149[23]|4295|5792))',
     '730' => '(?:8(?:5(?:8[0235-9]|4[0-358]|1[013-58]|6[1-356]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|0[1-35689]|6[126-8]|5[0-8]|3[01]|2[026])|7(?:12|87|2[02]|3[09]|0[167]|9[4-8])))',
     '731' => '(?:(?:0(?:19[2-7]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[2368]|29[2-4])|1(?:59[57]|795)|519[23578]|219[58]))',
-    '732' => '(?:8(?:5(?:6[4-68]|1[0-2]|0[1-57-9])|7(?:65|91)|652))',
+    '732' => '(?:8(?:5(?:6[4-68]|1[0-2]|0[13-57-9])|7(?:65|91)|652))',
     '733' => '(?:8(?:6(?:3[03]|2[1-6]|4[1-36-8]|7[0578]|0[18]|5[01]|6[069]|1[016])|5(?:01|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
     '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
     '735' => '(?:8(?:5(?:01|10|55|77|88)|6(?:70|86)))',
@@ -746,11 +746,11 @@ our %ZIP_TABLE = (
     '787' => '(?:(?:0[38]92|8501))',
     '788' => '(?:8(?:501|686))',
     '789' => '(?:(?:1(?:[29]92|795)|0392))',
-    '790' => '(?:8(?:5(?:4[0-356]|7[013-578]|9[05]|6[015-7]|2[04589]|1[0-4679]|3[0-79]|5[1-7]|8[013-9]|0[1-3589])|6(?:32|7[78]|6[015-7]|8[68]|5[0-35689])|7(?:87|9[135-8])))',
+    '790' => '(?:8(?:5(?:4[0-356]|7[013-578]|5[13-7]|9[05]|6[015-7]|2[04589]|1[0-4679]|3[0-79]|8[013-9]|0[1-3589])|6(?:32|7[78]|6[015-7]|8[68]|5[0-35689])|7(?:87|9[135-8])))',
     '791' => '(?:(?:8(?:5(?:51|2[3-578]|1[0-36-8]|3[01568]|0[125-8])|6(?:0[34]|7[1257]))|0(?:2(?:8[018]|9[257])|3(?:85|9[23578])|59[34])|3(?:19[2-8]|29[235]|[35]92)|(?:45|1[17])92|219[135]))',
     '792' => '(?:8(?:5(?:43|67|1[018]|8[0568]|5[05]|2[01]|0[15])|6(?:14|70|86)))',
     '793' => '(?:8(?:5(?:[58]5|0[19]|1[05])|601))',
-    '794' => '(?:(?:8(?:5(?:82|0[28]|1[18])|6(?:0[1278]|1[14]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
+    '794' => '(?:(?:8(?:5(?:82|1[018]|0[28])|6(?:0[1278]|1[14]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
     '795' => '(?:(?:8(?:5(?:0[124-8]|1[01])|60[1-3])|0392))',
     '796' => '(?:(?:0(?:29[235]|495|892)|850[12]))',
     '797' => '(?:(?:(?:02|1[257])92|85[01]1))',
@@ -904,7 +904,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|0[1-46])|765)|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|39[2-4]|59[24]|277)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|2(?:19[2-4]|39[24])|4(?:19[2-4]|392)|5(?:49[2-4]|292)|039[23]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|0[1-57]|1[0-2489]|5[0-35-9]|7[0-25-79]|4[013-5]|3[0-479]|8[0-35689])|6(?:6[0168]|5[0145]|7[078]|0[1-3568]|1[0-39]|4[01]|2[0-69]|8[016]|3[039])|7(?:5[013589]|3[023578]|0[7-9]|2[0-4]|1[01578]|9[48]|4[0-24-9])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|0[1-57]|1[0-2489]|5[0-35-9]|7[0-25-79]|4[013-5]|3[0-579]|8[0-35689])|6(?:6[0168]|5[0145]|7[078]|0[1-3568]|1[0-39]|4[01]|2[0-69]|8[016]|3[039])|7(?:5[013589]|3[023578]|0[7-9]|2[0-4]|1[01578]|9[48]|4[0-24-9])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
     '951' => '(?:8(?:5(?:3[0136]|4[045]|7[07]|5[0-256]|6[067]|8[01568]|0[1-68]|1[0-24589]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|501)|019[23]))',
@@ -923,7 +923,7 @@ our %ZIP_TABLE = (
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
     '967' => '(?:8501)',
     '968' => '(?:0498)',
-    '969' => '(?:(?:1(?:1(?:8[0168]|9[235])|[2-46]92|79[23])|6(?:19[256]|59[23]|292|495)|3(?:39[236]|59[2-4]|192)|0(?:29[26]|[34]92|197)|4495))',
+    '969' => '(?:(?:1(?:1(?:8[0168]|9[235])|[2-46]92|79[23])|6(?:19[256]|59[23]|292|495)|3(?:39[2356]|59[2-4]|192)|0(?:29[26]|[34]92|197)|4495))',
     '970' => '(?:(?:8(?:6(?:[23]5|[48]6|11)|5(?:[05]1|1[16]))|119[2-4]))',
     '971' => '(?:8615)',
     '972' => '(?:85(?:01|55))',
@@ -932,7 +932,7 @@ our %ZIP_TABLE = (
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[26-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
-    '980' => '(?:(?:8(?:4(?:6[06]|5[2-468]|7[78]|8[014-68]|2[0-369]|4[0235-8]|1[0145]|3[013569]|0[1-3578])|5(?:1[015]|4[3-6]|2[01569]|0[158]|5[05]|3[13-5]|6[0156]|7[013-9]|8[013578])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|8[56]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
+    '980' => '(?:(?:8(?:4(?:6[06]|5[2-468]|7[78]|8[014-68]|2[0-369]|1[0145]|3[013569]|0[1-3578]|4[235-8])|5(?:1[015]|4[3-6]|2[01569]|0[158]|5[05]|3[13-5]|6[0156]|7[013-9]|8[013578])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|8[56]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
     '983' => '(?:8(?:5(?:70|3[357]|8[45]|5[156]|4[03-5]|6[05]|1[0237]|2[02378]|0[124679])|6(?:22|39|0[12])))',
